@@ -8,9 +8,9 @@ import openapi_client
 import klaviyo_api.custom_retry as custom_retry
 from dataclasses import dataclass
 from typing import Callable, ClassVar
+from openapi_client.api import accounts_api
 from openapi_client.api import campaigns_api
 from openapi_client.api import catalogs_api
-from openapi_client.api import client_api
 from openapi_client.api import data_privacy_api
 from openapi_client.api import events_api
 from openapi_client.api import flows_api
@@ -30,18 +30,20 @@ class KlaviyoAPI:
     max_retries: int = 3
     test_host: str = ''
 
-    _REVISION = "2023-02-22"
+    _REVISION = "2023-07-15"
 
+    _STATUS_CODE_CONNECTION_RESET_BY_PEER = 104
     _STATUS_CODE_TOO_MANY_REQUESTS = 429
     _STATUS_CODE_SERVICE_UNAVAILABLE = 503
     _STATUS_CODE_GATEWAY_TIMEOUT = 504
     _STATUS_CODE_A_TIMEOUT_OCCURED = 524
 
     _RETRY_CODES = {
+        _STATUS_CODE_CONNECTION_RESET_BY_PEER,
         _STATUS_CODE_TOO_MANY_REQUESTS,
         _STATUS_CODE_SERVICE_UNAVAILABLE,
         _STATUS_CODE_GATEWAY_TIMEOUT,
-        _STATUS_CODE_A_TIMEOUT_OCCURED
+        _STATUS_CODE_A_TIMEOUT_OCCURED,
         }
 
     _CURSOR_SEARCH_TOKENS = ['page%5Bcursor%5D','page[cursor]']
@@ -73,6 +75,14 @@ class KlaviyoAPI:
         )
 
         
+        ## Adding Accounts to Client
+        self.Accounts=accounts_api.AccountsApi(self.api_client)
+        
+        ## Applying tenacity retry decorator to each endpoint in Accounts
+        self.Accounts.get_account=self._page_cursor_update(self.retry_logic(self.Accounts.get_account))
+        self.Accounts.get_accounts=self._page_cursor_update(self.retry_logic(self.Accounts.get_accounts))
+        
+        
         ## Adding Campaigns to Client
         self.Campaigns=campaigns_api.CampaignsApi(self.api_client)
         
@@ -84,9 +94,15 @@ class KlaviyoAPI:
         self.Campaigns.create_campaign_send_job=self._page_cursor_update(self.retry_logic(self.Campaigns.create_campaign_send_job))
         self.Campaigns.delete_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.delete_campaign))
         self.Campaigns.get_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign))
+        self.Campaigns.get_campaign_campaign_messages=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_campaign_messages))
         self.Campaigns.get_campaign_message=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message))
+        self.Campaigns.get_campaign_message_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message_campaign))
+        self.Campaigns.get_campaign_message_relationships_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message_relationships_campaign))
+        self.Campaigns.get_campaign_message_relationships_template=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message_relationships_template))
+        self.Campaigns.get_campaign_message_template=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message_template))
         self.Campaigns.get_campaign_recipient_estimation=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_recipient_estimation))
         self.Campaigns.get_campaign_recipient_estimation_job=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_recipient_estimation_job))
+        self.Campaigns.get_campaign_relationships_campaign_messages=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_relationships_campaign_messages))
         self.Campaigns.get_campaign_relationships_tags=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_relationships_tags))
         self.Campaigns.get_campaign_send_job=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_send_job))
         self.Campaigns.get_campaign_tags=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_tags))
@@ -100,6 +116,7 @@ class KlaviyoAPI:
         self.Catalogs=catalogs_api.CatalogsApi(self.api_client)
         
         ## Applying tenacity retry decorator to each endpoint in Catalogs
+        self.Catalogs.create_back_in_stock_subscription=self._page_cursor_update(self.retry_logic(self.Catalogs.create_back_in_stock_subscription))
         self.Catalogs.create_catalog_category=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_category))
         self.Catalogs.create_catalog_category_relationships_items=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_category_relationships_items))
         self.Catalogs.create_catalog_item=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_item))
@@ -155,15 +172,6 @@ class KlaviyoAPI:
         self.Catalogs.update_catalog_variant=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_variant))
         
         
-        ## Adding Client to Client
-        self.Client=client_api.ClientApi(self.api_client)
-        
-        ## Applying tenacity retry decorator to each endpoint in Client
-        self.Client.create_client_event=self._page_cursor_update(self.retry_logic(self.Client.create_client_event))
-        self.Client.create_client_profile=self._page_cursor_update(self.retry_logic(self.Client.create_client_profile))
-        self.Client.create_client_subscription=self._page_cursor_update(self.retry_logic(self.Client.create_client_subscription))
-        
-        
         ## Adding Data_Privacy to Client
         self.Data_Privacy=data_privacy_api.DataPrivacyApi(self.api_client)
         
@@ -177,10 +185,10 @@ class KlaviyoAPI:
         ## Applying tenacity retry decorator to each endpoint in Events
         self.Events.create_event=self._page_cursor_update(self.retry_logic(self.Events.create_event))
         self.Events.get_event=self._page_cursor_update(self.retry_logic(self.Events.get_event))
-        self.Events.get_event_metrics=self._page_cursor_update(self.retry_logic(self.Events.get_event_metrics))
-        self.Events.get_event_profiles=self._page_cursor_update(self.retry_logic(self.Events.get_event_profiles))
-        self.Events.get_event_relationships_metrics=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships_metrics))
-        self.Events.get_event_relationships_profiles=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships_profiles))
+        self.Events.get_event_metric=self._page_cursor_update(self.retry_logic(self.Events.get_event_metric))
+        self.Events.get_event_profile=self._page_cursor_update(self.retry_logic(self.Events.get_event_profile))
+        self.Events.get_event_relationships_metric=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships_metric))
+        self.Events.get_event_relationships_profile=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships_profile))
         self.Events.get_events=self._page_cursor_update(self.retry_logic(self.Events.get_events))
         
         
