@@ -10,16 +10,26 @@
 # sys.setrecursionlimit(n)
 
 from openapi_client.model.audiences_sub_object import AudiencesSubObject
+from openapi_client.model.back_in_stock_subscription_enum import BackInStockSubscriptionEnum
 from openapi_client.model.campaign_clone_query import CampaignCloneQuery
 from openapi_client.model.campaign_clone_query_resource_object import CampaignCloneQueryResourceObject
 from openapi_client.model.campaign_clone_query_resource_object_attributes import CampaignCloneQueryResourceObjectAttributes
 from openapi_client.model.campaign_create_query import CampaignCreateQuery
 from openapi_client.model.campaign_create_query_resource_object import CampaignCreateQueryResourceObject
 from openapi_client.model.campaign_create_query_resource_object_attributes import CampaignCreateQueryResourceObjectAttributes
+from openapi_client.model.campaign_create_query_resource_object_attributes_campaign_messages import CampaignCreateQueryResourceObjectAttributesCampaignMessages
+from openapi_client.model.campaign_create_query_resource_object_attributes_send_options import CampaignCreateQueryResourceObjectAttributesSendOptions
+from openapi_client.model.campaign_create_query_resource_object_attributes_tracking_options import CampaignCreateQueryResourceObjectAttributesTrackingOptions
 from openapi_client.model.campaign_enum import CampaignEnum
 from openapi_client.model.campaign_message_assign_template_query import CampaignMessageAssignTemplateQuery
 from openapi_client.model.campaign_message_assign_template_query_resource_object import CampaignMessageAssignTemplateQueryResourceObject
 from openapi_client.model.campaign_message_assign_template_query_resource_object_attributes import CampaignMessageAssignTemplateQueryResourceObjectAttributes
+from openapi_client.model.campaign_message_assign_template_query_resource_object_relationships import CampaignMessageAssignTemplateQueryResourceObjectRelationships
+from openapi_client.model.campaign_message_assign_template_query_resource_object_relationships_template import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplate
+from openapi_client.model.campaign_message_assign_template_query_resource_object_relationships_template_data import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplateData
+from openapi_client.model.campaign_message_create_query_resource_object import CampaignMessageCreateQueryResourceObject
+from openapi_client.model.campaign_message_create_query_resource_object_attributes import CampaignMessageCreateQueryResourceObjectAttributes
+from openapi_client.model.campaign_message_create_query_resource_object_attributes_content import CampaignMessageCreateQueryResourceObjectAttributesContent
 from openapi_client.model.campaign_message_enum import CampaignMessageEnum
 from openapi_client.model.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
 from openapi_client.model.campaign_message_partial_update_query_resource_object import CampaignMessagePartialUpdateQueryResourceObject
@@ -27,7 +37,6 @@ from openapi_client.model.campaign_message_partial_update_query_resource_object_
 from openapi_client.model.campaign_partial_update_query import CampaignPartialUpdateQuery
 from openapi_client.model.campaign_partial_update_query_resource_object import CampaignPartialUpdateQueryResourceObject
 from openapi_client.model.campaign_partial_update_query_resource_object_attributes import CampaignPartialUpdateQueryResourceObjectAttributes
-from openapi_client.model.campaign_recipient_estimation_enum import CampaignRecipientEstimationEnum
 from openapi_client.model.campaign_recipient_estimation_job_create_query import CampaignRecipientEstimationJobCreateQuery
 from openapi_client.model.campaign_recipient_estimation_job_create_query_resource_object import CampaignRecipientEstimationJobCreateQueryResourceObject
 from openapi_client.model.campaign_recipient_estimation_job_create_query_resource_object_attributes import CampaignRecipientEstimationJobCreateQueryResourceObjectAttributes
@@ -45,18 +54,21 @@ from openapi_client.model.catalog_category_bulk_update_job_enum import CatalogCa
 from openapi_client.model.catalog_category_create_job_create_query import CatalogCategoryCreateJobCreateQuery
 from openapi_client.model.catalog_category_create_job_create_query_resource_object import CatalogCategoryCreateJobCreateQueryResourceObject
 from openapi_client.model.catalog_category_create_job_create_query_resource_object_attributes import CatalogCategoryCreateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_category_create_job_create_query_resource_object_attributes_categories import CatalogCategoryCreateJobCreateQueryResourceObjectAttributesCategories
 from openapi_client.model.catalog_category_create_query import CatalogCategoryCreateQuery
 from openapi_client.model.catalog_category_create_query_resource_object import CatalogCategoryCreateQueryResourceObject
 from openapi_client.model.catalog_category_create_query_resource_object_attributes import CatalogCategoryCreateQueryResourceObjectAttributes
 from openapi_client.model.catalog_category_delete_job_create_query import CatalogCategoryDeleteJobCreateQuery
 from openapi_client.model.catalog_category_delete_job_create_query_resource_object import CatalogCategoryDeleteJobCreateQueryResourceObject
 from openapi_client.model.catalog_category_delete_job_create_query_resource_object_attributes import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_category_delete_job_create_query_resource_object_attributes_categories import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributesCategories
 from openapi_client.model.catalog_category_delete_query_resource_object import CatalogCategoryDeleteQueryResourceObject
 from openapi_client.model.catalog_category_enum import CatalogCategoryEnum
 from openapi_client.model.catalog_category_item_op import CatalogCategoryItemOp
 from openapi_client.model.catalog_category_update_job_create_query import CatalogCategoryUpdateJobCreateQuery
 from openapi_client.model.catalog_category_update_job_create_query_resource_object import CatalogCategoryUpdateJobCreateQueryResourceObject
 from openapi_client.model.catalog_category_update_job_create_query_resource_object_attributes import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_category_update_job_create_query_resource_object_attributes_categories import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributesCategories
 from openapi_client.model.catalog_category_update_query import CatalogCategoryUpdateQuery
 from openapi_client.model.catalog_category_update_query_resource_object import CatalogCategoryUpdateQueryResourceObject
 from openapi_client.model.catalog_category_update_query_resource_object_attributes import CatalogCategoryUpdateQueryResourceObjectAttributes
@@ -67,67 +79,71 @@ from openapi_client.model.catalog_item_bulk_create_job_enum import CatalogItemBu
 from openapi_client.model.catalog_item_bulk_delete_job_enum import CatalogItemBulkDeleteJobEnum
 from openapi_client.model.catalog_item_bulk_update_job_enum import CatalogItemBulkUpdateJobEnum
 from openapi_client.model.catalog_item_category_op import CatalogItemCategoryOp
+from openapi_client.model.catalog_item_category_op_data_inner import CatalogItemCategoryOpDataInner
 from openapi_client.model.catalog_item_create_job_create_query import CatalogItemCreateJobCreateQuery
 from openapi_client.model.catalog_item_create_job_create_query_resource_object import CatalogItemCreateJobCreateQueryResourceObject
 from openapi_client.model.catalog_item_create_job_create_query_resource_object_attributes import CatalogItemCreateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_item_create_job_create_query_resource_object_attributes_items import CatalogItemCreateJobCreateQueryResourceObjectAttributesItems
 from openapi_client.model.catalog_item_create_query import CatalogItemCreateQuery
 from openapi_client.model.catalog_item_create_query_resource_object import CatalogItemCreateQueryResourceObject
 from openapi_client.model.catalog_item_create_query_resource_object_attributes import CatalogItemCreateQueryResourceObjectAttributes
 from openapi_client.model.catalog_item_create_query_resource_object_relationships import CatalogItemCreateQueryResourceObjectRelationships
 from openapi_client.model.catalog_item_create_query_resource_object_relationships_categories import CatalogItemCreateQueryResourceObjectRelationshipsCategories
-from openapi_client.model.catalog_item_create_query_resource_object_relationships_categories_data_inner import CatalogItemCreateQueryResourceObjectRelationshipsCategoriesDataInner
 from openapi_client.model.catalog_item_delete_job_create_query import CatalogItemDeleteJobCreateQuery
 from openapi_client.model.catalog_item_delete_job_create_query_resource_object import CatalogItemDeleteJobCreateQueryResourceObject
 from openapi_client.model.catalog_item_delete_job_create_query_resource_object_attributes import CatalogItemDeleteJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_item_delete_job_create_query_resource_object_attributes_items import CatalogItemDeleteJobCreateQueryResourceObjectAttributesItems
 from openapi_client.model.catalog_item_delete_query_resource_object import CatalogItemDeleteQueryResourceObject
 from openapi_client.model.catalog_item_enum import CatalogItemEnum
 from openapi_client.model.catalog_item_update_job_create_query import CatalogItemUpdateJobCreateQuery
 from openapi_client.model.catalog_item_update_job_create_query_resource_object import CatalogItemUpdateJobCreateQueryResourceObject
 from openapi_client.model.catalog_item_update_job_create_query_resource_object_attributes import CatalogItemUpdateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_item_update_job_create_query_resource_object_attributes_items import CatalogItemUpdateJobCreateQueryResourceObjectAttributesItems
 from openapi_client.model.catalog_item_update_query import CatalogItemUpdateQuery
 from openapi_client.model.catalog_item_update_query_resource_object import CatalogItemUpdateQueryResourceObject
 from openapi_client.model.catalog_item_update_query_resource_object_attributes import CatalogItemUpdateQueryResourceObjectAttributes
-from openapi_client.model.catalog_job_error_payload import CatalogJobErrorPayload
 from openapi_client.model.catalog_variant_bulk_create_job_enum import CatalogVariantBulkCreateJobEnum
 from openapi_client.model.catalog_variant_bulk_delete_job_enum import CatalogVariantBulkDeleteJobEnum
 from openapi_client.model.catalog_variant_bulk_update_job_enum import CatalogVariantBulkUpdateJobEnum
 from openapi_client.model.catalog_variant_create_job_create_query import CatalogVariantCreateJobCreateQuery
 from openapi_client.model.catalog_variant_create_job_create_query_resource_object import CatalogVariantCreateJobCreateQueryResourceObject
 from openapi_client.model.catalog_variant_create_job_create_query_resource_object_attributes import CatalogVariantCreateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_variant_create_job_create_query_resource_object_attributes_variants import CatalogVariantCreateJobCreateQueryResourceObjectAttributesVariants
 from openapi_client.model.catalog_variant_create_query import CatalogVariantCreateQuery
 from openapi_client.model.catalog_variant_create_query_resource_object import CatalogVariantCreateQueryResourceObject
 from openapi_client.model.catalog_variant_create_query_resource_object_attributes import CatalogVariantCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_variant_create_query_resource_object_relationships import CatalogVariantCreateQueryResourceObjectRelationships
+from openapi_client.model.catalog_variant_create_query_resource_object_relationships_item import CatalogVariantCreateQueryResourceObjectRelationshipsItem
 from openapi_client.model.catalog_variant_delete_job_create_query import CatalogVariantDeleteJobCreateQuery
 from openapi_client.model.catalog_variant_delete_job_create_query_resource_object import CatalogVariantDeleteJobCreateQueryResourceObject
 from openapi_client.model.catalog_variant_delete_job_create_query_resource_object_attributes import CatalogVariantDeleteJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_variant_delete_job_create_query_resource_object_attributes_variants import CatalogVariantDeleteJobCreateQueryResourceObjectAttributesVariants
 from openapi_client.model.catalog_variant_delete_query_resource_object import CatalogVariantDeleteQueryResourceObject
 from openapi_client.model.catalog_variant_enum import CatalogVariantEnum
 from openapi_client.model.catalog_variant_update_job_create_query import CatalogVariantUpdateJobCreateQuery
 from openapi_client.model.catalog_variant_update_job_create_query_resource_object import CatalogVariantUpdateJobCreateQueryResourceObject
 from openapi_client.model.catalog_variant_update_job_create_query_resource_object_attributes import CatalogVariantUpdateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.catalog_variant_update_job_create_query_resource_object_attributes_variants import CatalogVariantUpdateJobCreateQueryResourceObjectAttributesVariants
 from openapi_client.model.catalog_variant_update_query import CatalogVariantUpdateQuery
 from openapi_client.model.catalog_variant_update_query_resource_object import CatalogVariantUpdateQueryResourceObject
 from openapi_client.model.catalog_variant_update_query_resource_object_attributes import CatalogVariantUpdateQueryResourceObjectAttributes
-from openapi_client.model.collection_links import CollectionLinks
-from openapi_client.model.content_sub_object import ContentSubObject
 from openapi_client.model.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
 from openapi_client.model.data_privacy_create_deletion_job_query_resource_object import DataPrivacyCreateDeletionJobQueryResourceObject
 from openapi_client.model.data_privacy_create_deletion_job_query_resource_object_attributes import DataPrivacyCreateDeletionJobQueryResourceObjectAttributes
+from openapi_client.model.data_privacy_create_deletion_job_query_resource_object_attributes_profile import DataPrivacyCreateDeletionJobQueryResourceObjectAttributesProfile
 from openapi_client.model.data_privacy_deletion_job_enum import DataPrivacyDeletionJobEnum
-from openapi_client.model.email_channel import EmailChannel
-from openapi_client.model.email_marketing import EmailMarketing
-from openapi_client.model.email_marketing_list_suppression import EmailMarketingListSuppression
-from openapi_client.model.email_marketing_suppression import EmailMarketingSuppression
-from openapi_client.model.email_message_content import EmailMessageContent
-from openapi_client.model.email_tracking_options import EmailTrackingOptions
-from openapi_client.model.error_source import ErrorSource
-from openapi_client.model.event_create_query import EventCreateQuery
-from openapi_client.model.event_create_query_resource_object import EventCreateQueryResourceObject
-from openapi_client.model.event_create_query_resource_object_attributes import EventCreateQueryResourceObjectAttributes
+from openapi_client.model.data_privacy_profile_query_resource_object import DataPrivacyProfileQueryResourceObject
+from openapi_client.model.data_privacy_profile_query_resource_object_attributes import DataPrivacyProfileQueryResourceObjectAttributes
+from openapi_client.model.email_content_sub_object import EmailContentSubObject
+from openapi_client.model.email_send_options_sub_object import EmailSendOptionsSubObject
+from openapi_client.model.email_tracking_options_sub_object import EmailTrackingOptionsSubObject
+from openapi_client.model.event_create_query_v2 import EventCreateQueryV2
+from openapi_client.model.event_create_query_v2_resource_object import EventCreateQueryV2ResourceObject
+from openapi_client.model.event_create_query_v2_resource_object_attributes import EventCreateQueryV2ResourceObjectAttributes
+from openapi_client.model.event_create_query_v2_resource_object_attributes_metric import EventCreateQueryV2ResourceObjectAttributesMetric
+from openapi_client.model.event_create_query_v2_resource_object_attributes_profile import EventCreateQueryV2ResourceObjectAttributesProfile
 from openapi_client.model.event_enum import EventEnum
-from openapi_client.model.flow_action_enum import FlowActionEnum
 from openapi_client.model.flow_enum import FlowEnum
-from openapi_client.model.flow_message_enum import FlowMessageEnum
 from openapi_client.model.flow_update_query import FlowUpdateQuery
 from openapi_client.model.flow_update_query_resource_object import FlowUpdateQueryResourceObject
 from openapi_client.model.flow_update_query_resource_object_attributes import FlowUpdateQueryResourceObjectAttributes
@@ -147,64 +163,84 @@ from openapi_client.model.metric_aggregate_enum import MetricAggregateEnum
 from openapi_client.model.metric_aggregate_query import MetricAggregateQuery
 from openapi_client.model.metric_aggregate_query_resource_object import MetricAggregateQueryResourceObject
 from openapi_client.model.metric_aggregate_query_resource_object_attributes import MetricAggregateQueryResourceObjectAttributes
-from openapi_client.model.metric_aggregate_row_dto import MetricAggregateRowDTO
-from openapi_client.model.metric_create_query import MetricCreateQuery
+from openapi_client.model.metric_create_query_resource_object import MetricCreateQueryResourceObject
+from openapi_client.model.metric_create_query_resource_object_attributes import MetricCreateQueryResourceObjectAttributes
 from openapi_client.model.metric_enum import MetricEnum
-from openapi_client.model.object_links import ObjectLinks
-from openapi_client.model.onsite_profile_create_query import OnsiteProfileCreateQuery
 from openapi_client.model.onsite_profile_create_query_resource_object import OnsiteProfileCreateQueryResourceObject
 from openapi_client.model.onsite_profile_create_query_resource_object_attributes import OnsiteProfileCreateQueryResourceObjectAttributes
 from openapi_client.model.onsite_profile_meta import OnsiteProfileMeta
-from openapi_client.model.onsite_profile_meta_identifiers import OnsiteProfileMetaIdentifiers
-from openapi_client.model.onsite_subscription_create_query import OnsiteSubscriptionCreateQuery
-from openapi_client.model.onsite_subscription_create_query_resource_object import OnsiteSubscriptionCreateQueryResourceObject
-from openapi_client.model.onsite_subscription_create_query_resource_object_attributes import OnsiteSubscriptionCreateQueryResourceObjectAttributes
-from openapi_client.model.predictive_analytics import PredictiveAnalytics
-from openapi_client.model.profile_aggregate_enum import ProfileAggregateEnum
 from openapi_client.model.profile_create_query import ProfileCreateQuery
 from openapi_client.model.profile_create_query_resource_object import ProfileCreateQueryResourceObject
 from openapi_client.model.profile_create_query_resource_object_attributes import ProfileCreateQueryResourceObjectAttributes
 from openapi_client.model.profile_enum import ProfileEnum
+from openapi_client.model.profile_identifier_dto_resource_object import ProfileIdentifierDTOResourceObject
+from openapi_client.model.profile_identifier_dto_resource_object_attributes import ProfileIdentifierDTOResourceObjectAttributes
 from openapi_client.model.profile_location import ProfileLocation
 from openapi_client.model.profile_location_latitude import ProfileLocationLatitude
 from openapi_client.model.profile_location_longitude import ProfileLocationLongitude
+from openapi_client.model.profile_meta import ProfileMeta
+from openapi_client.model.profile_meta_patch_properties import ProfileMetaPatchProperties
+from openapi_client.model.profile_meta_patch_properties_unset import ProfileMetaPatchPropertiesUnset
 from openapi_client.model.profile_partial_update_query import ProfilePartialUpdateQuery
 from openapi_client.model.profile_partial_update_query_resource_object import ProfilePartialUpdateQueryResourceObject
+from openapi_client.model.profile_partial_update_query_resource_object_attributes import ProfilePartialUpdateQueryResourceObjectAttributes
 from openapi_client.model.profile_subscription_bulk_create_job_enum import ProfileSubscriptionBulkCreateJobEnum
+from openapi_client.model.profile_subscription_bulk_delete_job_enum import ProfileSubscriptionBulkDeleteJobEnum
+from openapi_client.model.profile_subscription_create_query_resource_object import ProfileSubscriptionCreateQueryResourceObject
+from openapi_client.model.profile_subscription_create_query_resource_object_attributes import ProfileSubscriptionCreateQueryResourceObjectAttributes
+from openapi_client.model.profile_subscription_delete_query_resource_object import ProfileSubscriptionDeleteQueryResourceObject
+from openapi_client.model.profile_subscription_delete_query_resource_object_attributes import ProfileSubscriptionDeleteQueryResourceObjectAttributes
 from openapi_client.model.profile_suppression_bulk_create_job_enum import ProfileSuppressionBulkCreateJobEnum
-from openapi_client.model.profile_unsubscription_bulk_create_job_enum import ProfileUnsubscriptionBulkCreateJobEnum
-from openapi_client.model.profile_unsuppression_bulk_create_job_enum import ProfileUnsuppressionBulkCreateJobEnum
-from openapi_client.model.sms_channel import SMSChannel
-from openapi_client.model.sms_marketing import SMSMarketing
-from openapi_client.model.sms_message_content import SMSMessageContent
-from openapi_client.model.sms_render_options import SMSRenderOptions
-from openapi_client.model.sms_tracking_options import SMSTrackingOptions
+from openapi_client.model.profile_suppression_bulk_delete_job_enum import ProfileSuppressionBulkDeleteJobEnum
+from openapi_client.model.profile_suppression_create_query_resource_object import ProfileSuppressionCreateQueryResourceObject
+from openapi_client.model.profile_suppression_create_query_resource_object_attributes import ProfileSuppressionCreateQueryResourceObjectAttributes
+from openapi_client.model.profile_suppression_delete_query_resource_object import ProfileSuppressionDeleteQueryResourceObject
+from openapi_client.model.profile_suppression_delete_query_resource_object_attributes import ProfileSuppressionDeleteQueryResourceObjectAttributes
+from openapi_client.model.render_options_sub_object import RenderOptionsSubObject
+from openapi_client.model.sms_content_sub_object_create import SMSContentSubObjectCreate
+from openapi_client.model.sms_send_options_sub_object import SMSSendOptionsSubObject
+from openapi_client.model.sms_tracking_options_sub_object import SMSTrackingOptionsSubObject
 from openapi_client.model.sto_schedule_options import STOScheduleOptions
 from openapi_client.model.segment_enum import SegmentEnum
 from openapi_client.model.segment_partial_update_query import SegmentPartialUpdateQuery
 from openapi_client.model.segment_partial_update_query_resource_object import SegmentPartialUpdateQueryResourceObject
 from openapi_client.model.segment_partial_update_query_resource_object_attributes import SegmentPartialUpdateQueryResourceObjectAttributes
-from openapi_client.model.send_options import SendOptions
-from openapi_client.model.send_options_sub_object import SendOptionsSubObject
 from openapi_client.model.send_strategy_sub_object import SendStrategySubObject
-from openapi_client.model.send_time_sub_object import SendTimeSubObject
+from openapi_client.model.server_bis_subscription_create_query import ServerBISSubscriptionCreateQuery
+from openapi_client.model.server_bis_subscription_create_query_resource_object import ServerBISSubscriptionCreateQueryResourceObject
+from openapi_client.model.server_bis_subscription_create_query_resource_object_attributes import ServerBISSubscriptionCreateQueryResourceObjectAttributes
+from openapi_client.model.server_bis_subscription_create_query_resource_object_attributes_profile import ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile
+from openapi_client.model.server_bis_subscription_create_query_resource_object_relationships import ServerBISSubscriptionCreateQueryResourceObjectRelationships
+from openapi_client.model.server_bis_subscription_create_query_resource_object_relationships_variant import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariant
+from openapi_client.model.server_bis_subscription_create_query_resource_object_relationships_variant_data import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData
 from openapi_client.model.static_schedule_options import StaticScheduleOptions
-from openapi_client.model.subscription import Subscription
 from openapi_client.model.subscription_channels import SubscriptionChannels
 from openapi_client.model.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
 from openapi_client.model.subscription_create_job_create_query_resource_object import SubscriptionCreateJobCreateQueryResourceObject
 from openapi_client.model.subscription_create_job_create_query_resource_object_attributes import SubscriptionCreateJobCreateQueryResourceObjectAttributes
-from openapi_client.model.subscription_enum import SubscriptionEnum
-from openapi_client.model.subscriptions import Subscriptions
-from openapi_client.model.suppression import Suppression
+from openapi_client.model.subscription_create_job_create_query_resource_object_attributes_profiles import SubscriptionCreateJobCreateQueryResourceObjectAttributesProfiles
+from openapi_client.model.subscription_delete_job_create_query import SubscriptionDeleteJobCreateQuery
+from openapi_client.model.subscription_delete_job_create_query_resource_object import SubscriptionDeleteJobCreateQueryResourceObject
+from openapi_client.model.subscription_delete_job_create_query_resource_object_attributes import SubscriptionDeleteJobCreateQueryResourceObjectAttributes
+from openapi_client.model.subscription_delete_job_create_query_resource_object_attributes_profiles import SubscriptionDeleteJobCreateQueryResourceObjectAttributesProfiles
+from openapi_client.model.subscription_delete_job_create_query_resource_object_relationships import SubscriptionDeleteJobCreateQueryResourceObjectRelationships
+from openapi_client.model.subscription_delete_job_create_query_resource_object_relationships_list import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsList
+from openapi_client.model.subscription_delete_job_create_query_resource_object_relationships_list_data import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsListData
 from openapi_client.model.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
 from openapi_client.model.suppression_create_job_create_query_resource_object import SuppressionCreateJobCreateQueryResourceObject
 from openapi_client.model.suppression_create_job_create_query_resource_object_attributes import SuppressionCreateJobCreateQueryResourceObjectAttributes
+from openapi_client.model.suppression_create_job_create_query_resource_object_attributes_profiles import SuppressionCreateJobCreateQueryResourceObjectAttributesProfiles
+from openapi_client.model.suppression_delete_job_create_query import SuppressionDeleteJobCreateQuery
+from openapi_client.model.suppression_delete_job_create_query_resource_object import SuppressionDeleteJobCreateQueryResourceObject
+from openapi_client.model.suppression_delete_job_create_query_resource_object_attributes import SuppressionDeleteJobCreateQueryResourceObjectAttributes
+from openapi_client.model.suppression_delete_job_create_query_resource_object_attributes_profiles import SuppressionDeleteJobCreateQueryResourceObjectAttributesProfiles
 from openapi_client.model.tag_campaign_op import TagCampaignOp
 from openapi_client.model.tag_campaign_op_data_inner import TagCampaignOpDataInner
 from openapi_client.model.tag_create_query import TagCreateQuery
 from openapi_client.model.tag_create_query_resource_object import TagCreateQueryResourceObject
-from openapi_client.model.tag_create_query_resource_object_attributes import TagCreateQueryResourceObjectAttributes
+from openapi_client.model.tag_create_query_resource_object_relationships import TagCreateQueryResourceObjectRelationships
+from openapi_client.model.tag_create_query_resource_object_relationships_tag_group import TagCreateQueryResourceObjectRelationshipsTagGroup
+from openapi_client.model.tag_create_query_resource_object_relationships_tag_group_data import TagCreateQueryResourceObjectRelationshipsTagGroupData
 from openapi_client.model.tag_enum import TagEnum
 from openapi_client.model.tag_flow_op import TagFlowOp
 from openapi_client.model.tag_flow_op_data_inner import TagFlowOpDataInner
@@ -235,15 +271,5 @@ from openapi_client.model.template_render_query_resource_object_attributes impor
 from openapi_client.model.template_update_query import TemplateUpdateQuery
 from openapi_client.model.template_update_query_resource_object import TemplateUpdateQueryResourceObject
 from openapi_client.model.template_update_query_resource_object_attributes import TemplateUpdateQueryResourceObjectAttributes
-from openapi_client.model.test_api_analytics_sample_enum import TestApiAnalyticsSampleEnum
-from openapi_client.model.test_list_enum import TestListEnum
 from openapi_client.model.throttled_schedule_options import ThrottledScheduleOptions
-from openapi_client.model.tracking_options_sub_object import TrackingOptionsSubObject
 from openapi_client.model.utm_params_sub_object import UTMParamsSubObject
-from openapi_client.model.unsubscription_create_job_create_query import UnsubscriptionCreateJobCreateQuery
-from openapi_client.model.unsubscription_create_job_create_query_resource_object import UnsubscriptionCreateJobCreateQueryResourceObject
-from openapi_client.model.unsubscription_create_job_create_query_resource_object_attributes import UnsubscriptionCreateJobCreateQueryResourceObjectAttributes
-from openapi_client.model.unsuppression_create_job_create_query import UnsuppressionCreateJobCreateQuery
-from openapi_client.model.unsuppression_create_job_create_query_resource_object import UnsuppressionCreateJobCreateQueryResourceObject
-from openapi_client.model.unsuppression_create_job_create_query_resource_object_attributes import UnsuppressionCreateJobCreateQueryResourceObjectAttributes
-from openapi_client.model.utm_param_info import UtmParamInfo
